# histr

I am only getting started, this package intends to be one stop solution for any kind of manipulation on Devanagari string, at the outset I have the following goals:

- [ ] Tokenize the Devanagari string at phoneme level, i.e. break down "अंकित" to ["अं", "कि", "त"]
- [ ] Identify and autocorrect (optionally) the text like अंंिकत to अंकित

I will keep adding to the list as came across more usecases or feature requests from downstream users

If you have any ideas on how to do this or you want to improve upon my work, PR(s) are always welcome.